@@ -28,7 +28,7 @@ def main():
     print((colors.BOLD))
     print(" isbntools - app and framework for 'all things ISBN'")
     print((colors.RESET))
-    print((' Copyright (C) 2014-2021  Alexandre Lima Conde, Version %s' %
+    print((' Copyright (C) 2014-2023  Alexandre Lima Conde, Version %s' %
            __version__))
     print('')
     print(' License LGPL v3')
@@ -62,16 +62,3 @@ def main():
         RDDATE[0:8],
         colors.RESET,
     ))
-    print('')
-
-    # check for updates and pypi packages
-    print(' Checking %sonline%s services ... %sWAIT%s' %
-          (colors.BOLD, colors.RESET, colors.BOLD, colors.RESET))
-    try:
-        from isbntools.contrib.modules.report import check_pypi
-
-        if check_pypi() == 1:
-            raise
-    except:
-        print(' %spypi%s "search" services are %sNOT%s available now!' %
-              (colors.BOLD, colors.RESET, colors.BOLD, colors.RESET))
